<?php
namespace FiloBlu\ExtProductVideo\Observer;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Filesystem\Driver\File;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem;
use Psr\Log\LoggerInterface;

class ProductSaveAfter implements ObserverInterface
{
    /**
     * @var File
     */
    private $fileUtility;
    /**
     * @var Filesystem
     */
    private $filesystem;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * ProductSaveAfter constructor.
     * @param File $fileUtility
     * @param Filesystem $filesystem
     * @param LoggerInterface $logger
     */
    public function __construct(
        File $fileUtility,
        Filesystem $filesystem,
        LoggerInterface $logger){
        $this->fileUtility = $fileUtility;
        $this->filesystem = $filesystem;
        $this->logger = $logger;
    }


    public function execute(Observer $observer)
    {
        $product = $observer->getProduct();
        if($product->dataHasChangedFor('media_gallery')){
            //remove file
            $galleryEntry =$product->getMediaGallery();
            if($galleryEntry && isset($galleryEntry['images'])){
                $gallery = $galleryEntry['images'];
                foreach ($gallery as $item) {
                    if(isset($item['removed']) && $item['removed']==1 && isset($item['media_type']) && $item['media_type']=='external-video'){
                        //check if is video and delete file from disk
                        $videoUrl =$item['video_url'] ?? false;
                        if($videoUrl && isset($item['video_provider_default']) && $item['video_provider_default']=='custom'){
                            $fileReader = $this->filesystem->getDirectoryRead(DirectoryList::MEDIA);
                            $videoFile = str_replace('media/','',$fileReader->getAbsolutePath()).$videoUrl;
                            if($this->fileUtility->isExists($videoFile)){
                                $this->fileUtility->deleteFile($videoFile);
                            }else{
                                $this->logger->critical("FiloBlu_ExtProductVideo/Observer/ProductSaveAfter : file $videoFile not found");
                            }
                        }
                    }
                }
            }

        }
    }

}
